@@ -6,8 +6,8 @@ function(FILEPATH,SAMPLESIZES,MEASURES,ATESTRESULTFILENAME,SUMMARYFILENAME,TIMEP
 	{
 		TIMEPOINTANALYSED<-TIMEPOINTS[n]
 
-		ATESTSFILENAME<-paste(ATESTRESULTFILENAME,"_",TIMEPOINTANALYSED,".csv",sep="")
-		SUMMARYFILENAMEFULL<-paste(SUMMARYFILENAME,"_",TIMEPOINTANALYSED,".csv",sep="")
+		ATESTSFILENAME<-paste(ATESTRESULTFILENAME,"_",TIMEPOINTANALYSED,sep="")
+		SUMMARYFILENAMEFULL<-paste(SUMMARYFILENAME,"_",TIMEPOINTANALYSED,sep="")
 
 		aa_sampleSizeSummary(FILEPATH,SAMPLESIZES,MEASURES,ATESTSFILENAME,SUMMARYFILENAMEFULL)
 	}
